@@ -7,6 +7,32 @@ from cookiecutter.main import cookiecutter
 from cookiecutter.generate import generate_files
 
 
+def patch_dask_gateway_extra_config(config):
+    """Basically the current dask_gateway helm chart only allows one
+    update to extraContainerConfig and extraPodConfig for the workers
+    and scheduler. Thus we need to copy the configuration done in
+    these settings. The only critical one is mounting the conda store
+    directory.
+
+    """
+    conda_store_volume = {
+        "name": "conda-store",
+        "persistentVolumeClaim": {"claimName": "conda-store-dev-share"},
+    }
+
+    if "profiles" in config and "dask_worker" in config["profiles"]:
+        for worker_name, worker_config in config["profiles"]["dask_worker"].items():
+            if "worker_extra_pod_config" in worker_config:
+                if "volumes" in worker_config["worker_extra_pod_config"]:
+                    worker_config["worker_extra_pod_config"]["volumes"].append(
+                        conda_store_volume
+                    )
+                else:
+                    worker_config["worker_extra_pod_config"]["volumes"] = [
+                        conda_store_volume
+                    ]
+
+
 def render_default_template(output_directory, config_filename=None, force=False):
     import qhub_ops
 
@@ -41,6 +67,7 @@ def render_template(
         with filename.open() as f:
             config = yaml.safe_load(f)
             config["repo_directory"] = repo_directory
+            patch_dask_gateway_extra_config(config)
 
         with (input_directory / "cookiecutter.json").open() as f:
             config = collections.ChainMap(config, json.load(f))
